HLS.Playlist.Tag.Key (HTTP Live Streaming (HLS) library v3.0.8)
View SourceEXT-X-KEY tag implementation.
Specifies how to decrypt Media Segments. It applies to every Media Segment and to every Media Initialization Section declared by an EXT-X-MAP tag that appears between it and the next EXT-X-KEY tag in the Playlist file with the same KEYFORMAT attribute (or the end of the Playlist file).
See RFC 8216, section 4.3.2.4.
Summary
Functions
Marshals a key attribute map into the tag value string.